@@ -132,7 +132,7 @@ c! define huge 3d arrays which crash.
         subroutine tile_roundness(volrank,n,m,ngens,xgens,
      /             ygens,roundfac,roundpix,x,y)
         implicit none
-        include "constants.inc"
+        include "constants.h"
         integer n,m,i,j,ngens,ind,npix(ngens),k
         real*8 volrank(n,m),area(ngens),sumrad(ngens),dist
         real*8 xgens(ngens),ygens(ngens),roundfac(ngens)
